.. _api-reference:

*************
API Reference
*************

.. automodapi:: hvpy
   :no-inheritance-diagram:

.. automodapi:: hvpy.core

.. automodapi:: hvpy.io
   :no-inheritance-diagram:

.. automodapi:: hvpy.parameters
   :allowed-package-names: hvpy.api_groups

.. automodapi:: hvpy.datasource
   :no-inheritance-diagram:

.. automodapi:: hvpy.event
   :no-inheritance-diagram:

.. automodapi:: hvpy.utils
